start

# Adobe Flex properties files

Adobe Flex applications use .properties files similar to Java properties, but with UTF-8 encoding, and therefore prop2po and po2prop is used for conversion.

We welcome more testing and feedback, but based on our solid support for properties, this probably works perfectly.

## References

- http://livedocs.adobe.com/flex/3/html/l10n_3.html - Description for Adobe Flex properties files